@@ -14,8 +14,6 @@ describe 'aodh::api' do
     { :enabled           => true,
       :manage_service    => true,
       :package_ensure    => 'latest',
-      :port              => '8042',
-      :host              => '0.0.0.0',
     }
   end
 
@@ -34,11 +32,12 @@ describe 'aodh::api' do
     end
 
     it 'configures api' do
-      is_expected.to contain_aodh_config('api/host').with_value( params[:host] )
-      is_expected.to contain_aodh_config('api/port').with_value( params[:port] )
       is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value( 'services' )
       is_expected.to contain_aodh_config('api/paste_config').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_aodh_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('aodh_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        :max_request_body_size        => '<SERVICE DEFAULT>',
+      )
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -75,7 +74,19 @@ describe 'aodh::api' do
         params.merge!({:enable_proxy_headers_parsing => true })
       end
 
-      it { is_expected.to contain_aodh_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+      it { is_expected.to contain_oslo__middleware('aodh_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
+    end
+
+    context 'with max_request_body_size' do
+      before do
+        params.merge!({:max_request_body_size => '102400' })
+      end
+
+      it { is_expected.to contain_oslo__middleware('aodh_config').with(
+        :max_request_body_size => '102400',
+      )}
     end
 
     context 'with paste_config' do
